@@ -6,8 +6,9 @@ import (
 )
 
 const (
-	defaultFocusable = false
-	defaultTitle     = "ResourceUsage"
+	defaultFocusable       = false
+	defaultRefreshInterval = "1s"
+	defaultTitle           = "ResourceUsage"
 )
 
 type Settings struct {
@@ -28,6 +29,7 @@ func NewSettingsFromYAML(name string, ymlConfig *config.Config, globalConfig *co
 		showMem:     ymlConfig.UBool("showMem", true),
 		showSwp:     ymlConfig.UBool("showSwp", true),
 	}
+	settings.Common.RefreshInterval = cfg.ParseTimeString(ymlConfig, "refreshInterval", defaultRefreshInterval)
 
 	return &settings
 }
